// eqsolver project main.go
package main

import (
	"fmt"
	"time"

	"./atompkg"
)

// version info for display
var versioninfo = "v1.3 - mouser@donationcoder.com - 11/15/14"

func main() {
	fmt.Println("Eqsolver Project " + versioninfo)

	// for calculating elapsed time
	starttime := time.Now()

	// options
	out_solutionthresholdcount := -1
	out_maxcharsperline := 150

	// create an EquationSet to hold primitives and solutions
	var eqprimitives atompkg.EquationSet
	var solutionset atompkg.SolutionSet

	// stop adding solutions for a target value after 'stop' hits; completely remove all solutions to a target after 'kill' hits
	// these settings can drastically reduce memory usage and allow us to solve for larger number sets by discarding most computed expressions
	solutionset.Set_maxhits_stop(5)
	solutionset.Set_maxhits_kill(20)

	// stick some test numbers in it
	var initialnums = [...] int {3,4,5, 6}
	//var initialnums = [...] int { 3,6,15}
	//var initialnums = [...] int { 15, 2, 6, 3}
	//var initialnums = [...] int { 2, 3, 6, 15 }
	//var initialnums = [...] int { 2,3,4,5,6,7 }
	//var initialnums = [...] int { 2,3,4,5,6,7,8 }
	//var initialnums = [...] int { 12,23,34,5,66,47,8 }
	//var initialnums = [...] int { 12,23,34,5,66,47,8 }
	//var initialnums = [...] int {3, 5, 7, 11, 13, 17, 19, 23}
	//
	eqprimitives.AddFromIntegerSlice(initialnums[:])

	// show info
	fmt.Print("Combining these values: ")
	fmt.Println(initialnums)

	// now solve by finding all expressions formed from the pimitives
	solutionset.SolveFromEquationSet(eqprimitives)

	// dump the solutions more nicely
	solutionset.DumpSolutionsNicely(out_solutionthresholdcount, out_maxcharsperline)

	// display elapsed time
	elapsedtime := time.Since(starttime)
	fmt.Print("Elapsed time: ")
	fmt.Println(elapsedtime)
}
